@@ -2,7 +2,7 @@ package Acme::MyFirstModule::DRPENGUIN;
 
 use 5.006;
 use strict;
-ue warnings;
+use warnings;
 
 =head1 NAME
 
@@ -14,7 +14,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 
 =head1 SYNOPSIS
@@ -48,7 +48,6 @@ sub function1 {
 
 sub function2 {
 }
-
 =head1 AUTHOR
 
 Leo Chan, C<< <penguin02007 at gmail.com> >>
